DirFlags

Struct DirFlags 

pub struct DirFlags { /* private fields */ }
‘Dir::new()’ creates a new DirFlags object with default (O_CLOEXEC) flags. One can then freely add/remove flags to the set. The final open calls will add O_DIRECTORY and O_PATH as applicable/supported but not verify or remove any defined flags. This allows passing flags the ‘openat’ implementation is not even aware about. Thus the open call may fail with some error when one constructed an invalid flag set.

Implementations

Source

impl DirFlags

pub fn with(self, flags: c_int) -> DirFlags

Sets the given flags

pub fn without(self, flags: c_int) -> DirFlags

Clears the given flags

pub fn get_flags(&self) -> c_int

Queries current flags

pub fn open<P: AsPath>(&self, path: P) -> Result<Dir>

Open a directory descriptor at specified path